# This file is part of dds_example.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__all__ = ["BaseTopic"]

import ddsutil


class BaseTopic:
    """Basic topic information from a specified IDL file.

    Parameters
    ----------
    component : `Component`
        Information for the DDS component that has this topic.
    name : `str`
        Topic name.
    """

    def __init__(self, component, name):
        self.name = name
        self.type = ddsutil.get_dds_classes_from_idl(component.idl_path, name)
        self.DataType = self.type.topic_data_class
        topic_name = name.replace("::", "_")
        topic_qos = component.domain.topic_qos
        self.topic = self.type.register_topic(
            component.domain.participant, topic_name, topic_qos
        )
