# This file is part of dds_example.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

__all__ = ["WriteTopic"]

import time

from .base_topic import BaseTopic


class WriteTopic(BaseTopic):
    """Write a DDS topic.

    Parameters
    ----------
    component : `Component`
        SAL component information
    name : `str`
        Topic name.
    """

    def __init__(self, *, component, name):
        super().__init__(component=component, name=name)
        self.writer = component.publisher.create_datawriter(
            self.topic, component.domain.writer_qos
        )

    def write(self, data):
        """Write a sample.

        Parameters
        ----------
        data : ``self.DataType``
            Data to write.
        """

        data.source_timestamp = time.time()
        self.writer.write(data)
