# This file is part of dds_example.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import asyncio

import ddsexample


async def main():
    with ddsexample.Domain(qos_path="DefaultQos.xml") as domain:
        component = ddsexample.Component(domain=domain, idl_path="Thermometer.idl")
        read_topic = ddsexample.ReadTopic(
            component=component, name="Thermometer::reading"
        )

        write_topic = ddsexample.WriteTopic(
            component=component, name="Thermometer::reading"
        )
        data = write_topic.DataType()
        data.double0 = [1.0, 2.0, 3.0, 4.0, 5.0]
        print("wrote:", data.double0)
        write_topic.write(data)

        while not read_topic.data:
            await asyncio.sleep(0.1)
        print("read: ", read_topic.data[0].data.double0)


asyncio.get_event_loop().run_until_complete(main())
